:orphan:

.. title:: uplot documentation

.. module:: uplot

###################
uplot documentation
###################

Framework to display different plots in displayio. Similar to widget
Take a look in the `examples <https://circuitpython-uplot.readthedocs.io/en/latest/examples.html>`_ section in RTD to see the gallery

uplot is to be used with CircuitPython as some of the behind the curtains methods are
in the CircuitPython core and could differ from MicroPython or Python


Quick Start
==============

.. include:: ../docs/quick_start.rst


Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 2

    api

.. toctree::
    :caption: Other Links

    Download from GitHub <https://github.com/jposada202020/CircuitPython_uplot/releases/latest>
    Download Library Bundle <https://circuitpython.org/libraries>
